@@ -44,11 +44,11 @@ class ELECTRE_I(MCDA):
             for i in range(n_rows):
                 if i != alt:
                     Cab = 0
-                    for col in range(n_rows):
-                        a = self.df_normalized.iloc[alt, col+1]
-                        b = self.df_normalized.iloc[i, col+1]
+                    for col in range(1, self.df_normalized.shape[1]):
+                        a = self.df_normalized.iloc[alt, col]
+                        b = self.df_normalized.iloc[i, col]
                         if a >= b:
-                            Cab = Cab + self.weights[col]
+                            Cab = Cab + self.weights[col-1]
                         else:
                             Cab = Cab + 0
                     Cab = Cab/W
@@ -70,10 +70,10 @@ class ELECTRE_I(MCDA):
                 if i != alt:
                     Dab = []
                     count_negatives = 0
-                    for col in range(n_rows):
-                        a = self.df_normalized.iloc[alt, col+1]
-                        b = self.df_normalized.iloc[i, col+1]
-                        d = (b - a)/S[col]
+                    for col in range(1, self.df_normalized.shape[1]):
+                        a = self.df_normalized.iloc[alt, col]
+                        b = self.df_normalized.iloc[i, col]
+                        d = (b - a)/S[col-1]
                         Dab.append(d)
                         if d < 0:
                             count_negatives = count_negatives + 1
