@@ -123,11 +123,12 @@ class ENSEMBLE(MCDA):
         df_hard["voting"] = df_hard.iloc[:,:].agg(lambda x: x.value_counts().index[0], axis=1)
         df_hard["rank"] = df_hard.iloc[:,:].agg(lambda x: x.value_counts().index[0], axis=1)
 
+
         # set a tie when entropy = 1
-        for x in range(0, df_hard.shape[0]-1):
+        for x in range(0, df_hard.shape[0]):
             elements = []
-            for y in range(0, df_hard.shape[1]-4):
-                if df_hard.iloc[x,y] not in elements: 
+            for y in range(0, df_hard.shape[1]-3):
+                if float(df_hard.iloc[x,y]) not in elements: 
                     elements.append(df_hard.iloc[x,y])
                     if (df_hard.shape[1]-3) == len(elements):
                         df_hard.iloc[x, -2] = "a tie"
